@@ -141,7 +141,7 @@ static void register_panel_action_exportqif(GtkAction *action, gpointer user_dat
 {
 struct register_panel_data *data = user_data;
 gchar *filename;
-	
+
 	DB( g_print("(qif) test qif export\n\n") );
 
 	if( ui_file_chooser_qif(GTK_WINDOW(data->window), &filename) == TRUE )
@@ -788,10 +788,11 @@ gboolean result;
 		Transaction *src_txn;
 		gint type = 0;
 
+			homebank_app_date_get_julian();
+			
 			if(action == ACTION_ACCOUNT_ADD)
 			{
 				DB( g_print("(transaction) add multiple\n") );
-				//date = GLOBALS->today;
 				src_txn = da_transaction_malloc();
 				src_txn->date = GLOBALS->today;
 				src_txn->kacc = data->accnum;
@@ -811,7 +812,7 @@ gboolean result;
 				/* clone source transaction */
 				data->cur_ope = da_transaction_clone (src_txn);
 
-				if( type == TRANSACTION_EDIT_ADD && PREFS->heritdate == FALSE ) //fix: 318733
+				if( PREFS->heritdate == FALSE ) //fix: 318733 / 1335285
 					data->cur_ope->date = GLOBALS->today;
 
 				deftransaction_set_transaction(dialog, data->cur_ope);
@@ -1764,6 +1765,9 @@ static const gchar *ui_info =
 "	<toolbar name='ToolBar'>"
 "		<toolitem action='Filter'/>"
 "		<toolitem action='Assign'/>"
+"			<separator/>"
+"		<toolitem action='ExportQIF'/>"
+"		<toolitem action='ExportCSV'/>"
 "	</toolbar>"
 "</ui>";
 
@@ -1999,7 +2003,7 @@ GError *error = NULL;
 	gtk_box_pack_start (GTK_BOX (mainbox), sw, TRUE, TRUE, 0);
 
 	/* toolbars */
-	hbox = gtk_hbox_new (FALSE, HB_BOX_SPACING);
+	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (mainbox), hbox, FALSE, FALSE, 0);
 
 	widget = gtk_ui_manager_get_widget (ui, "/TxnBar");
@@ -2011,6 +2015,18 @@ GError *error = NULL;
 	data->TB_tools = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
+    #ifdef G_OS_WIN32
+    if(PREFS->toolbar_style == 0)
+    {
+        gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
+        gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_tools));
+    }
+    else
+    {
+        gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
+        gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_tools), PREFS->toolbar_style-1);
+    }
+    #endif
 
 	//todo: should move this
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
