@@ -464,6 +464,8 @@ GdkPixbuf *pixbuf;
 	gtk_dialog_run (GTK_DIALOG (about));
 
 	gtk_widget_destroy (about);
+
+	g_object_unref (pixbuf);
 }
 
 
@@ -1014,7 +1016,7 @@ gint account = 1, count;
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	/* init the transaction */
-	date = GLOBALS->today;
+	date = homebank_app_date_get_julian();
 	if(data->acc != NULL)
 		account = data->acc->key;
 
@@ -1504,6 +1506,8 @@ GDate *date;
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_upc));
 	gtk_list_store_clear (GTK_LIST_STORE(model));
 
+	homebank_app_date_get_julian();
+
 	maxpostdate = scheduled_date_get_post_max();
 
 	date = g_date_new_julian (maxpostdate);
@@ -1747,7 +1751,8 @@ gdouble gtbank, gttoday, gtfuture;
 	while (elt != NULL)
 	{
 		acc = elt->data;
-		if( !(acc->flags & (AF_CLOSED|AF_NOREPORT|AF_NOSUMMARY)) )
+		//#1339572
+		if( !(acc->flags & (AF_CLOSED|AF_NOSUMMARY)) )
 		{
 			DB( g_print(" -> insert %d:%s\n", acc->key, acc->name) );
 
@@ -2141,7 +2146,7 @@ gboolean retval = FALSE;
  	PREFS->wal_vpaned = gtk_paned_get_position(GTK_PANED(data->vpaned));
  	PREFS->wal_hpaned = gtk_paned_get_position(GTK_PANED(data->hpaned));
 
-	DB( g_print(" -> paned position is %d\n", PREFS->wal_vpaned) );
+	DB( g_print(" - vpaned=%d hpaned=%d\n", PREFS->wal_vpaned, PREFS->wal_hpaned) );
 
 	//todo
 	if(ui_dialog_msg_savechanges(widget, NULL) == FALSE)
@@ -2688,6 +2693,7 @@ GtkToolItem *toolitem;
 GtkWidget *create_hbfile_window(GtkWidget *do_widget)
 {
 struct hbfile_data *data;
+struct WinGeometry *wg;
 GtkWidget *mainvbox, *vbox, *vpaned, *hpaned;
 GtkWidget *widget;
 GtkWidget *window;
@@ -2708,6 +2714,17 @@ GtkAction *action;
 	data->window = window;
 	GLOBALS->mainwindow = window;
 
+	//setup, init and show window
+	wg = &PREFS->wal_wg;
+	if(wg->s == 0)
+	{
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+		gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
+	}
+	else
+		gtk_window_maximize(GTK_WINDOW(window));
+
+	gtk_widget_show (window);
 
 	mainvbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
@@ -2738,16 +2755,25 @@ GtkWidget *bar, *label;
 		data->hpaned = hpaned;
 		gtk_paned_pack1 (GTK_PANED(vpaned), hpaned, FALSE, FALSE);
 
+		widget = ui_mainwindow_scheduled_create(data);
+		gtk_paned_pack2 (GTK_PANED(vpaned), widget, FALSE, FALSE);
+
 		widget = ui_mainwindow_create_youraccounts(data);
-		gtk_paned_pack1 (GTK_PANED(hpaned), widget, TRUE, FALSE);
+		gtk_paned_pack1 (GTK_PANED(hpaned), widget, FALSE, FALSE);
 
 		widget = ui_mainwindow_create_topspending(data);
 		gtk_paned_pack2 (GTK_PANED(hpaned), widget, FALSE, FALSE);
 
-		widget = ui_mainwindow_scheduled_create(data);
-		gtk_paned_pack2 (GTK_PANED(vpaned), widget, FALSE, FALSE);
-	
 
+	DB( g_print(" - vpaned=%d hpaned=%d\n", PREFS->wal_vpaned, PREFS->wal_hpaned) );
+
+	if(PREFS->wal_hpaned > 0)
+		gtk_paned_set_position(GTK_PANED(data->hpaned), PREFS->wal_hpaned);
+	if(PREFS->wal_vpaned > 0)
+		gtk_paned_set_position(GTK_PANED(data->vpaned), PREFS->wal_vpaned);
+
+	gtk_widget_show_all (window);
+	
 	//todo: move this elsewhere
 	DB( g_print(" - setup stuff\n") );
 
@@ -2755,12 +2781,7 @@ GtkWidget *bar, *label;
 	filter_default_all_set(data->filter);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_range), PREFS->date_range_wal);
 
-	DB( g_print(" - vpaned=%d hpaned=%d\n", PREFS->wal_vpaned, PREFS->wal_hpaned) );
-	
-	if(PREFS->wal_vpaned > 0)
-		gtk_paned_set_position(GTK_PANED(data->vpaned), PREFS->wal_vpaned);
-	if(PREFS->wal_hpaned > 0)
-		gtk_paned_set_position(GTK_PANED(data->hpaned), PREFS->wal_hpaned);
+
 
 	action = gtk_ui_manager_get_action(data->manager, "/MenuBar/ViewMenu/Toolbar");
 	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), PREFS->wal_toolbar);
