@@ -63,6 +63,8 @@ enum
 	PAYMODE_EPAYMENT,
 	PAYMODE_DEPOSIT,
 	PAYMODE_FEE,
+	/* 4.6 new paymode */
+	PAYMODE_DIRECTDEBIT,
 //	PAYMODE_,
 	NUM_PAYMODE_MAX
 };
