@@ -81,7 +81,7 @@ GList *tmplist = g_list_first(list);
 
 static gint da_archive_glist_compare_func(Archive *a, Archive *b)
 {
-	return (g_utf8_collate(a->wording, b->wording));
+	return hb_string_utf8_compare(a->wording, b->wording);
 }
 
 
