@@ -322,6 +322,8 @@ GList *lcat, *list;
 		case FLT_STATUS_UNRECONCILED:
 			flt->option[FILTER_STATUS] = 2;
 			flt->reconciled = TRUE;
+			//#1336882
+			flt->reminded = FALSE;
 			break;
 	}
 
