@@ -355,6 +355,15 @@ GList *tmplist = g_list_first(GLOBALS->ope_list);
 }
 
 
+// nota: this is called only when loading xml file
+gboolean da_transaction_prepend(Transaction *item)
+{
+	GLOBALS->ope_list = g_list_prepend(GLOBALS->ope_list, item);
+	da_transaction_insert_memo(item);
+	return TRUE;
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 guint32
@@ -405,6 +414,7 @@ void da_transaction_consistency(Transaction *item)
 Account *acc;
 Category *cat;
 Payee *pay;
+guint i, nbsplit;
 
 	// check account exists
 	acc = da_acc_get(item->kacc);
@@ -422,6 +432,19 @@ Payee *pay;
 		item->kcat = 0;
 	}
 
+	// check split category #1340142
+	nbsplit = da_transaction_splits_count(item);
+	for(i=0;i<nbsplit;i++)
+	{
+	Split *split = item->splits[i];
+		cat = da_cat_get(split->kcat);
+		if(cat == NULL)
+		{
+			g_warning("txn consistency: fixed invalid split cat %d", split->kcat);
+			split->kcat = 0;
+		}
+	}
+	
 	// check payee exists
 	pay = da_pay_get(item->kpay);
 	if(pay == NULL)
