@@ -378,7 +378,7 @@ gint i, j;
 
 				//all attribute loaded: append
 				// we use prepend here, the list will be reversed later for perf reason
-				GLOBALS->ope_list = g_list_prepend(GLOBALS->ope_list, entry);
+				da_transaction_prepend(entry);
 			}
 		}
 		break;
@@ -519,6 +519,8 @@ gboolean rc;
 			}
 			if( version <= 0.7 )
 				homebank_upgrade_to_v08();
+			if( version <= 0.8 )
+				hbfile_sanity_check();
 
 			// next ?
 			
@@ -799,11 +801,16 @@ static void hb_xml_append_txt(GString *gstring, gchar *attrname, gchar *value)
 	}
 }
 
+static void hb_xml_append_int0(GString *gstring, gchar *attrname, guint32 value)
+{
+	g_string_append_printf(gstring, "%s=\"%d\" ", attrname, value);
+}
+	
 static void hb_xml_append_int(GString *gstring, gchar *attrname, guint32 value)
 {
 	if(value != 0)
 	{
-		g_string_append_printf(gstring, "%s=\"%d\" ", attrname, value);
+		hb_xml_append_int0(gstring, attrname, value);
 	}
 }
 
@@ -833,7 +840,7 @@ GString *node;
 	
 	hb_xml_append_txt(node, "title", title);
 	hb_xml_append_int(node, "car_category", GLOBALS->vehicle_category);
-	hb_xml_append_int(node, "auto_smode", GLOBALS->auto_smode);
+	hb_xml_append_int0(node, "auto_smode", GLOBALS->auto_smode);
 	hb_xml_append_int(node, "auto_weekday", GLOBALS->auto_weekday);
 	hb_xml_append_int(node, "auto_nbdays", GLOBALS->auto_nbdays);
 
