@@ -684,7 +684,16 @@ build_package_paths (void)
 }
 
 
-
+guint32 homebank_app_date_get_julian(void)
+{
+GDate *date;
+	//init global default value
+	date = g_date_new();
+	g_date_set_time_t(date, time(NULL));
+	GLOBALS->today = g_date_get_julian(date);
+	g_date_free(date);
+	return GLOBALS->today;
+}
 
 
 static gboolean homebank_check_app_dir_migrate_file(gchar *srcdir, gchar *dstdir, gchar *filename)
@@ -827,7 +836,6 @@ static void homebank_cleanup()
 */
 static gboolean homebank_setup()
 {
-GDate *date;
 
 	DB( g_print("\n[homebank] setup\n") );
 
@@ -851,11 +859,8 @@ GDate *date;
 	load_nainex_icons();
 	load_pref_icons();
 
-	//init global default value
-	date = g_date_new();
-	g_date_set_time_t(date, time(NULL));
-	GLOBALS->today = g_date_get_julian(date);
-	g_date_free(date);
+	homebank_app_date_get_julian();
+
 
 	#if MYDEBUG == 1
 
@@ -1051,18 +1056,7 @@ gboolean openlast;
 
 		if(mainwin)
 		{
-		struct WinGeometry *wg;
 
-			//setup, init and show window
-			wg = &PREFS->wal_wg;
-			if(wg->s == 0)
-			{
-				gtk_window_move(GTK_WINDOW(mainwin), wg->l, wg->t);
-				gtk_window_resize(GTK_WINDOW(mainwin), wg->w, wg->h);
-			}
-			else
-				gtk_window_maximize(GTK_WINDOW(mainwin));
-				
 			//todo: pause on splash
 			if( PREFS->showsplash == TRUE )
 			{
@@ -1071,7 +1065,6 @@ gboolean openlast;
 				gtk_widget_destroy(splash);
 			}
 
-		    gtk_widget_show_all (mainwin);
 
 #if HB_UNSTABLE == TRUE
 /*			GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW(mainwin),
