@@ -662,10 +662,10 @@ extern int ofx_STATUS_msg;*/
 #ifdef G_OS_WIN32
 	//#932959: windows don't like utf8 path, so convert
 	gchar *file = g_win32_locale_filename_from_utf8(filename);
-	libofx_proc_file(libofx_context, file, OFX);
+	libofx_proc_file(libofx_context, file, AUTODETECT);
 	g_free(file);
 #else
-	libofx_proc_file(libofx_context, filename, OFX);
+	libofx_proc_file(libofx_context, filename, AUTODETECT);
 #endif
 
 	libofx_free_context(libofx_context);
@@ -1764,7 +1764,6 @@ static void import_acc_affect_onRowActivated (GtkTreeView        *treeview,
 }
 
 
-
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 /**
