@@ -27,10 +27,12 @@ enum
 	LST_DSPUPC_DATAS,
 	LST_DSPUPC_PAYEE,
 	LST_DSPUPC_WORDING,
-	LST_DSPUPC_AMOUNT,
+	LST_DSPUPC_EXPENSE,
+	LST_DSPUPC_INCOME,
 	LST_DSPUPC_ACCOUNT,
-	LST_DSPUPC_NEXTON,
+	LST_DSPUPC_DATE,
 	LST_DSPUPC_REMAINING,
+	LST_DSPUPC_NB_LATE,
 	NUM_LST_DSPUPC
 };
 
