@@ -268,14 +268,14 @@ gint nbmonth;
 
 static gdouble budget_compute_result(gdouble budget, gdouble spent)
 {
-gdouble result;
+gdouble retval;
 
 	//original formula
 	//result = ABS(budget) - ABS(spent);
 
-	result = spent - budget;
+	retval = spent - budget;
 
-	return result;
+	return retval;
 }
 
 
@@ -374,32 +374,36 @@ struct repbudget_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	DB( g_print("(repbudget) toggle detail\n") );
+	DB( g_print("(repbudget) update detail\n") );
 
-	if(data->detail)
+	if(GTK_IS_TREE_VIEW(data->LV_report))
 	{
-	GtkTreeSelection *treeselection;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	guint key;
-
-		treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
-
-		if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+		if(data->detail)
 		{
-			gtk_tree_model_get(model, &iter, LST_BUDGET_KEY, &key, -1);
+		GtkTreeSelection *treeselection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+		guint key;
 
-			//DB( g_print(" - active is %d\n", pos) );
+			treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
 
-			repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
+			if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+			{
+				gtk_tree_model_get(model, &iter, LST_BUDGET_KEY, &key, -1);
+
+				//DB( g_print(" - active is %d\n", pos) );
+
+				repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
+			}
+
+
+			gtk_widget_show(data->GR_detail);
 		}
+		else
+			gtk_widget_hide(data->GR_detail);
 
-
-
-		gtk_widget_show(data->GR_detail);
+		
 	}
-	else
-		gtk_widget_hide(data->GR_detail);
 }
 
 static void repbudget_detail(GtkWidget *widget, gpointer user_data)
