@@ -1173,30 +1173,34 @@ struct ui_repdist_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	if(data->detail)
+	if(GTK_IS_TREE_VIEW(data->LV_report))
 	{
-	GtkTreeSelection *treeselection;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	guint key;
-
-		treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
-
-		if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+		if(data->detail)
 		{
-			gtk_tree_model_get(model, &iter, LST_REPDIST_KEY, &key, -1);
+		GtkTreeSelection *treeselection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+		guint key;
 
-			DB( g_print(" - active is %d\n", key) );
+			treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
 
-			ui_repdist_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
+			if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+			{
+				gtk_tree_model_get(model, &iter, LST_REPDIST_KEY, &key, -1);
+
+				DB( g_print(" - active is %d\n", key) );
+
+				ui_repdist_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
+			}
+
+
+
+			gtk_widget_show(data->GR_detail);
 		}
+		else
+			gtk_widget_hide(data->GR_detail);
 
-
-
-		gtk_widget_show(data->GR_detail);
 	}
-	else
-		gtk_widget_hide(data->GR_detail);
 }
 
 
@@ -1266,15 +1270,18 @@ GtkTreeViewColumn *column;
 
 	data->rate ^= 1;
 
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 2);
-	gtk_tree_view_column_set_visible(column, data->rate);
+	if(GTK_IS_TREE_VIEW(data->LV_report))
+	{
 
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 4);
-	gtk_tree_view_column_set_visible(column, data->rate);
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 2);
+		gtk_tree_view_column_set_visible(column, data->rate);
 
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 6);
-	gtk_tree_view_column_set_visible(column, data->rate);
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 4);
+		gtk_tree_view_column_set_visible(column, data->rate);
 
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW(data->LV_report), 6);
+		gtk_tree_view_column_set_visible(column, data->rate);
+	}
 
 }
 
@@ -1891,7 +1898,7 @@ GtkTreeViewColumn  *column;
 static gint ui_list_repdist_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
 gint sortcol = GPOINTER_TO_INT(userdata);
-gint ret = 0;
+gint retval = 0;
 gint pos1, pos2;
 gdouble val1, val2;
 
@@ -1907,15 +1914,15 @@ gdouble val1, val2;
 	switch(sortcol)
 	{
 		case LST_REPDIST_POS:
-			ret = pos2 - pos1;
+			retval = pos2 - pos1;
 			break;
 		default:
-			ret = (ABS(val1) - ABS(val2)) > 0 ? 1 : -1;
+			retval = (ABS(val1) - ABS(val2)) > 0 ? 1 : -1;
 			break;
 	}
 
 	//DB( g_print(" sort %d=%d or %.2f=%.2f :: %d\n", pos1,pos2, val1, val2, ret) );
 
-    return ret;
+    return retval;
   }
 
