@@ -438,17 +438,24 @@ guint32 selkey;
 							{
 								split = ope->splits[i];
 								catentry = da_cat_get(split->kcat);
-								if( selkey == catentry->parent || selkey == catentry->key )
-									include = TRUE;
+								if(catentry != NULL)	//#1340142
+								{
+									if( selkey == catentry->parent || selkey == catentry->key )
+										include = TRUE;
+
+								}
 							}
 						}
 						else
 						{							
 							catentry = da_cat_get(ope->kcat);
-							if( selkey == catentry->parent || selkey == catentry->key )
-								include = TRUE;
+							if(catentry != NULL)	//#1340142
+							{
+								if( selkey == catentry->parent || selkey == catentry->key )
+									include = TRUE;
+
+							}
 						}
-						
 					}
 						break;
 					case FOR_REPTIME_PAYEE:
@@ -785,15 +792,21 @@ guint32 selkey;
 							{
 								split = ope->splits[i];
 								catentry = da_cat_get(split->kcat);
-								if( selkey == catentry->parent || selkey == catentry->key )
-									include = TRUE;
+								if(catentry != NULL)	//#1340142
+								{
+									if( selkey == catentry->parent || selkey == catentry->key )
+										include = TRUE;
+								}
 							}
 						}
 						else
 						{							
 							catentry = da_cat_get(ope->kcat);
-							if( selkey == catentry->parent || selkey == catentry->key )
-								include = TRUE;
+							if(catentry != NULL)	//#1340142
+							{
+								if( selkey == catentry->parent || selkey == catentry->key )
+									include = TRUE;
+							}
 						}
 						
 					}
@@ -845,8 +858,11 @@ guint32 selkey;
 						{
 							split = ope->splits[i];
 							catentry = da_cat_get(split->kcat);
-							if( selkey == catentry->parent || selkey == catentry->key )
-								trn_amount += split->amount;
+							if(catentry != NULL)	//#1340142
+							{
+								if( selkey == catentry->parent || selkey == catentry->key )
+									trn_amount += split->amount;
+							}
 						}
 					}
 					else
@@ -1652,7 +1668,7 @@ GtkTreeViewColumn  *column;
 static gint ui_list_reptime_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
 gint sortcol = GPOINTER_TO_INT(userdata);
-gint ret = 0;
+gint retval = 0;
 gint pos1, pos2;
 gdouble val1, val2;
 
@@ -1670,12 +1686,12 @@ gdouble val1, val2;
 */
 
 	if(sortcol == LST_REPTIME_POS)
-		ret = pos2 - pos1;
+		retval = pos2 - pos1;
 	else
-		ret = (ABS(val1) - ABS(val2)) > 0 ? 1 : -1;
+		retval = (ABS(val1) - ABS(val2)) > 0 ? 1 : -1;
 
 	//DB( g_print(" sort %d=%d or %.2f=%.2f :: %d\n", pos1,pos2, val1, val2, ret) );
 
-    return ret;
+    return retval;
   }
 
