@@ -324,28 +324,16 @@ ui_acc_listview_toggled_cb (GtkCellRendererToggle *cell,
 static gint
 ui_acc_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result = 0;
+gint retval = 0;
 Account *entry1, *entry2;
 //gchar *name1, *name2;
 
     gtk_tree_model_get(model, a, LST_DEFACC_DATAS, &entry1, -1);
     gtk_tree_model_get(model, b, LST_DEFACC_DATAS, &entry2, -1);
 
-/*
-	name1 = entry1->name;
-	name2 = entry2->name;
-    if (name1 == NULL || name2 == NULL)
-    {
-        result = (name1 == NULL) ? -1 : 1;
-    }
-    else
-    {
-        result = g_utf8_collate(name1,name2);
-    }
-*/
-	result = entry1->pos - entry2->pos;
+	retval = entry1->pos - entry2->pos;
 
-    return result;
+    return retval;
 }
 
 static void
@@ -655,7 +643,7 @@ gint field = GPOINTER_TO_INT(user_data);
 static gchar *dialog_get_name(gchar *title, gchar *origname, GtkWindow *parentwindow)
 {
 GtkWidget *dialog, *content, *mainvbox, *getwidget;
-gchar *rettxt = NULL;
+gchar *retval = NULL;
 	
 		dialog = gtk_dialog_new_with_buttons (title,
 						    GTK_WINDOW (parentwindow),
@@ -696,7 +684,7 @@ gchar *rettxt = NULL;
 			/* ignore if entry is empty */
 			if (name && *name)
 			{
-				rettxt = g_strdup(name);
+				retval = g_strdup(name);
 			}
 	    }
 
@@ -704,7 +692,7 @@ gchar *rettxt = NULL;
 		gtk_widget_destroy (dialog);
 	
 
-	return rettxt;
+	return retval;
 }
 
 
@@ -782,7 +770,6 @@ struct ui_acc_manage_data *data;
 GtkTreeSelection *selection;
 GtkTreeModel		 *model;
 GtkTreeIter			 iter;
-
 Account *item;
 
 	DB( g_print("\n(ui_acc_manage_set)\n") );
