@@ -62,25 +62,12 @@ static GtkWidget *ui_arc_listview_new(void);
 */
 static gint ui_arc_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result = 0;
 Archive *entry1, *entry2;
-gchar *name1, *name2;
 
 	gtk_tree_model_get(model, a, LST_DEFARC_DATAS, &entry1, -1);
 	gtk_tree_model_get(model, b, LST_DEFARC_DATAS, &entry2, -1);
 
-	name1 = entry1->wording;
-	name2 = entry2->wording;
-    if (name1 == NULL || name2 == NULL)
-    {
-      result = (name1 == NULL) ? -1 : 1;
-    }
-    else
-    {
-      result = g_utf8_collate(name1,name2);
-    }
-
-    return result;
+    return hb_string_utf8_compare(entry1->wording, entry2->wording);
 }
 
 
