@@ -74,27 +74,12 @@ ui_asg_listview_toggled_cb (GtkCellRendererToggle *cell,
 static gint
 ui_asg_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result = 0;
 Assign *entry1, *entry2;
-gchar *name1, *name2;
 
     gtk_tree_model_get(model, a, LST_DEFASG_DATAS, &entry1, -1);
     gtk_tree_model_get(model, b, LST_DEFASG_DATAS, &entry2, -1);
 
-
-	name1 = entry1->name;
-	name2 = entry2->name;
-    if (name1 == NULL || name2 == NULL)
-    {
-        result = (name1 == NULL) ? -1 : 1;
-    }
-    else
-    {
-        result = g_utf8_collate(name1,name2);
-    }
-
-
-    return result;
+    return hb_string_utf8_compare(entry1->name, entry2->name);
 }
 
 static void
