@@ -77,30 +77,19 @@ static void ui_bud_manage_selection(GtkTreeSelection *treeselection, gpointer us
 */
 static gint ui_bud_listview_compare_funct (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result = 0;
+gint retval = 0;
 Category *entry1, *entry2;
-gchar *name1, *name2;
 
 	gtk_tree_model_get(model, a, LST_DEFCAT_DATAS, &entry1, -1);
 	gtk_tree_model_get(model, b, LST_DEFCAT_DATAS, &entry2, -1);
 
-	result = (entry1->flags & GF_INCOME) - (entry2->flags & GF_INCOME);
-	if(!result)
+	retval = (entry1->flags & GF_INCOME) - (entry2->flags & GF_INCOME);
+	if(!retval)
 	{
-		name1 = entry1->name;
-		name2 = entry2->name;
-        if (name1 == NULL || name2 == NULL)
-        {
-          //if (name1 == NULL && name2 == NULL)
-          result = (name1 == NULL) ? -1 : 1;
-        }
-        else
-        {
-          result = g_utf8_collate(name1,name2);
-        }
+		retval = hb_string_utf8_compare(entry1->name, entry2->name);
 	}
 
-    return result;
+    return retval;
 }
 
 /*
