@@ -227,6 +227,7 @@ gchar type;
 		gtk_list_store_set (GTK_LIST_STORE(ctx->model), &iter,
 			0, fullname,
 			1, name,
+		    2, item->parent == 0 ? 1 : 0,
 			-1);
 
 		g_free(fullname);
@@ -287,32 +288,24 @@ struct catPopContext ctx;
 static gint
 ui_cat_comboboxentry_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata)
 {
-gint ret = 0;
+gint retval = 0;
 gchar *name1, *name2;
 
     gtk_tree_model_get(model, a, 0, &name1, -1);
     gtk_tree_model_get(model, b, 0, &name2, -1);
 
-    if (name1 == NULL || name2 == NULL)
-    {
-        if (name1 == NULL && name2 == NULL)
-        goto end;
-
-        ret = (name1 == NULL) ? -1 : 1;
-    }
-    else
-    {
-        ret = g_utf8_collate(name1,name2);
-    }
-
-
-  end:
-
-    g_free(name1);
+	retval = hb_string_utf8_compare(name1, name2);
+/*
+	retval = (entry1->flags & GF_INCOME) - (entry2->flags & GF_INCOME);
+	if(!retval)
+	{
+		retval = hb_string_utf8_compare(entry1->name, entry2->name);
+	}
+*/
     g_free(name2);
+    g_free(name1);
 
-
-  	return ret;
+  	return retval;
   }
 
 
@@ -325,18 +318,76 @@ ui_cat_comboboxentry_test (GtkCellLayout   *cell_layout,
 		   gpointer         data)
 {
 gchar *name;
+gboolean subcat;
+gint style;
 
+//PANGO_STYLE_ITALIC
+	
 	gtk_tree_model_get(tree_model, iter,
 		1, &name,
+	    2, &subcat,
 		-1);
 
-	if( name == NULL )
-		g_object_set(cell, "text", _("(no category)"), NULL);	//todo: seems not used
-	else
-		g_object_set(cell, "text", name, NULL);
+	style = subcat == 0 ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL;
 
+	if( name == NULL )
+		name = _("(no category)");  //todo: not used
+	
+	g_object_set(cell,
+	    "style", style,
+		"text", name,
+		NULL);
 }
 
+
+
+static gboolean
+ui_cat_comboboxentry_completion_func (GtkEntryCompletion *completion,
+                                              const gchar        *key,
+                                              GtkTreeIter        *iter,
+                                              gpointer            user_data)
+{
+  gchar *item = NULL;
+  gchar *normalized_string;
+  gchar *case_normalized_string;
+
+  gboolean ret = FALSE;
+
+  GtkTreeModel *model;
+
+  model = gtk_entry_completion_get_model (completion);
+
+  gtk_tree_model_get (model, iter,
+                      0, &item,
+                      -1);
+
+  if (item != NULL)
+    {
+      normalized_string = g_utf8_normalize (item, -1, G_NORMALIZE_ALL);
+
+      if (normalized_string != NULL)
+        {
+          case_normalized_string = g_utf8_casefold (normalized_string, -1);
+
+			//g_print("match '%s' for '%s' ?\n", key, case_normalized_string);
+		//if (!strncmp (key, case_normalized_string, strlen (key)))
+          if (g_strstr_len (case_normalized_string, strlen (case_normalized_string), key ))
+			{
+        		ret = TRUE;
+				//	g_print(" ==> yes !\n");
+				
+			}
+				
+          g_free (case_normalized_string);
+        }
+      g_free (normalized_string);
+    }
+  g_free (item);
+
+  return ret;
+}
+
+
 /**
  * ui_cat_comboboxentry_new:
  *
@@ -356,15 +407,18 @@ GtkCellRenderer    *renderer;
     DB( g_print ("ui_cat_comboboxentry_new()\n") );
 
 
-	store = gtk_list_store_new (2,
+	store = gtk_list_store_new (3,
 		G_TYPE_STRING, 			//fullname Car:Fuel
-		G_TYPE_STRING 			//name	Car or Fuel
+		G_TYPE_STRING, 			//name	Car or Fuel
+	    G_TYPE_BOOLEAN			//subcat = 1
 		);
 	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), ui_cat_comboboxentry_compare_func, NULL, NULL);
 
     completion = gtk_entry_completion_new ();
     gtk_entry_completion_set_model (completion, GTK_TREE_MODEL(store));
 	g_object_set(completion, "text-column", 0, NULL);
+	gtk_entry_completion_set_match_func(completion, ui_cat_comboboxentry_completion_func, NULL, NULL);
+	gtk_entry_completion_set_minimum_key_length(completion, 2);
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion), renderer, TRUE);
@@ -442,29 +496,18 @@ ui_cat_listview_fixed_toggled (GtkCellRendererToggle *cell,
 static gint
 ui_cat_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result = 0;
+gint retval = 0;
 Category *entry1, *entry2;
-gchar *name1, *name2;
 
 	gtk_tree_model_get(model, a, LST_DEFCAT_DATAS, &entry1, -1);
 	gtk_tree_model_get(model, b, LST_DEFCAT_DATAS, &entry2, -1);
 
-	result = (entry1->flags & GF_INCOME) - (entry2->flags & GF_INCOME);
-	if(!result)
+	retval = (entry1->flags & GF_INCOME) - (entry2->flags & GF_INCOME);
+	if(!retval)
 	{
-		name1 = entry1->name;
-		name2 = entry2->name;
-        if (name1 == NULL || name2 == NULL)
-        {
-          //if (name1 == NULL && name2 == NULL)
-          result = (name1 == NULL) ? -1 : 1;
-        }
-        else
-        {
-          result = g_utf8_collate(name1,name2);
-        }
+		retval = hb_string_utf8_compare(entry1->name, entry2->name);
 	}
-    return result;
+    return retval;
 }
 
 
@@ -885,8 +928,8 @@ static void ui_cat_manage_filter_text_handler (GtkEntry    *entry,
                           gpointer     data)
 {
 GtkEditable *editable = GTK_EDITABLE(entry);
-int i, count=0;
-gchar *result = g_new (gchar, length);
+gint i, count=0, pos;
+gchar *result = g_new0 (gchar, length+1);
 
   for (i=0; i < length; i++)
   {
@@ -900,7 +943,7 @@ gchar *result = g_new (gchar, length);
     g_signal_handlers_block_by_func (G_OBJECT (editable),
                                      G_CALLBACK (ui_cat_manage_filter_text_handler),
                                      data);
-    gtk_editable_insert_text (editable, result, count, position);
+    gtk_editable_insert_text (editable, result, count, &pos);
     g_signal_handlers_unblock_by_func (G_OBJECT (editable),
                                        G_CALLBACK (ui_cat_manage_filter_text_handler),
                                        data);
@@ -1183,10 +1226,10 @@ GtkTreeIter			 iter;
 static void ui_cat_manage_dialog_move_entry_cb(GtkComboBox *widget, gpointer user_data)
 {
 GtkDialog *window = user_data;
-guint dstkey;
+gchar *buffer;
 
-	dstkey = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(widget));
-	gtk_dialog_set_response_sensitive(GTK_DIALOG(window), GTK_RESPONSE_ACCEPT, dstkey != 0 ? TRUE : FALSE);
+	buffer = (gchar *)gtk_entry_get_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (widget))));
+	gtk_dialog_set_response_sensitive(GTK_DIALOG(window), GTK_RESPONSE_ACCEPT, strlen(buffer) > 0 ? TRUE : FALSE);
 }
 
 
@@ -1281,7 +1324,8 @@ GtkTreeIter			 iter;
 				ui_cat_listview_remove_selected(GTK_TREE_VIEW(data->LV_cat));
 
 				//add the new category into listview
-				ui_cat_listview_add(GTK_TREE_VIEW(data->LV_cat), newcat, NULL);
+				if(newcat)
+					ui_cat_listview_add(GTK_TREE_VIEW(data->LV_cat), newcat, NULL);
 
 				data->change++;
 			}
