@@ -53,7 +53,7 @@ gint ui_dialog_msg_question(GtkWindow *parent, gchar *title, gchar *message_form
 GtkWidget *dialog;
 gchar* msg = NULL;
 va_list args;
-gint result;
+gint retval;
 
 	dialog = gtk_message_dialog_new (GTK_WINDOW(parent),
 	                                  GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -76,11 +76,11 @@ gint result;
 
 	gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 	
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	retval = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (dialog);
 
-	return result;
+	return retval;
 }
 
 /*
