@@ -1436,13 +1436,13 @@ GtkWidget *window, *content, *mainbox, *notebook, *label, *page;
 
 
 	//wait for the user
-	gint result;	// = 55;
+	gint retval;	// = 55;
 
 	//while( result == 55 )
 	//{
-		result = gtk_dialog_run (GTK_DIALOG (window));
+		retval = gtk_dialog_run (GTK_DIALOG (window));
 
-		switch (result)
+		switch (retval)
 	    {
 		case GTK_RESPONSE_ACCEPT:
 		   //do_application_specific_something ();
@@ -1470,5 +1470,5 @@ GtkWidget *window, *content, *mainbox, *notebook, *label, *page;
 
 	DB( g_print(" all ok\n") );
 
-	return result;
+	return retval;
 }
