@@ -416,31 +416,23 @@ static LangName languagenames[] =
 static gint
 ui_language_combobox_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata)
 {
-gint ret = 0;
+gint retval = 0;
+gchar *code1, *code2;
 gchar *name1, *name2;
 
-    gtk_tree_model_get(model, a, 0, &name1, -1);
-    gtk_tree_model_get(model, b, 0, &name2, -1);
+    gtk_tree_model_get(model, a, 0, &code1, 1, &name1, -1);
+    gtk_tree_model_get(model, b, 0, &code2, 1, &name2, -1);
 
-    if (name1 == NULL || name2 == NULL)
-    {
-        if (name1 == NULL && name2 == NULL)
-        goto end;
+	//keep system laguage on top
+	if(code1 == NULL) name1 = NULL;
+	if(code2 == NULL) name2 = NULL;
+	
+    retval = hb_string_utf8_compare(name1, name2);
 
-        ret = (name1 == NULL) ? -1 : 1;
-    }
-    else
-    {
-        ret = g_utf8_collate(name1,name2);
-    }
-
-
-  end:
-
-    g_free(name1);
     g_free(name2);
+    g_free(name1);
 
-  	return ret;
+  	return retval;
 }
 
 
