@@ -450,17 +450,17 @@ is_separator (GtkTreeModel *model,
 	      gpointer      data)
 {
   //GtkTreePath *path;
-  gboolean result;
+  gboolean retval;
   gchar *txt;
 
 	gtk_tree_model_get (model, iter, 0, &txt, -1);
 
-	result = *txt == 0 ? TRUE : FALSE;
+	retval = *txt == 0 ? TRUE : FALSE;
   //path = gtk_tree_model_get_path (model, iter);
   //result = gtk_tree_path_get_indices (path)[0] == 4;
   //gtk_tree_path_free (path);
 
-  return result;
+  return retval;
 }
 
 static void
